@@ -25,6 +25,8 @@ from indykite_sdk.indykite.config.v1beta1.model_pb2 import google_dot_protobuf_d
 from indykite_sdk.indykite.identity.v1beta2.import_pb2 import Email as EmailIdentity
 from indykite_sdk.model.is_authorized import IsAuthorizedResource
 from indykite_sdk.model.tenant import Tenant
+from indykite_sdk.indykite.identity.v1beta2 import attributes_pb2 as attributes
+from indykite_sdk.identity import helper
 import logging
 
 
@@ -47,6 +49,11 @@ def main():
     introspect_parser = subparsers.add_parser("introspect")
     introspect_parser.add_argument("user_token", help="JWT bearer token")
 
+    # SESSION_INTROSPECT
+    session_introspect_parser = subparsers.add_parser("session_introspect")
+    session_introspect_parser.add_argument("tenant_id", help="gid ID of the tenant")
+    session_introspect_parser.add_argument("access_token", help="JWT bearer token")
+
     # VERIFY
     verify_parser = subparsers.add_parser("verify")
     verify_parser.add_argument("verification_token", help="Token from email to verify")
@@ -536,6 +543,10 @@ Property ID and value of the property where the value is a reference
     cancel_invitation = subparsers.add_parser("cancel_invitation")
     cancel_invitation.add_argument("reference_id", help="external ID of the invitation reference")
 
+    # register_digital_twin_without_credential
+    register_digital_twin_without_credential = subparsers.add_parser("register_digital_twin_without_credential")
+    register_digital_twin_without_credential.add_argument("tenant_id", help="gid ID of the tenant")
+
     args = parser.parse_args()
     local = args.local
     client = IdentityClient(local)
@@ -546,12 +557,21 @@ Property ID and value of the property where the value is a reference
 
     if command == "introspect":
         user_token = args.user_token
-        token_info = client.introspect_token(user_token)
+        token_info = client.token_introspect(user_token)
         if token_info is not None:
             print_response(token_info)
         else:
             print("Invalid token")
 
+    elif command == "session_introspect":
+        tenant_id = args.tenant_id
+        access_token = args.access_token
+        session_response = client.session_introspect(tenant_id, access_token)
+        if session_response is not None:
+            print_response(session_response)
+        else:
+            print("Invalid session token")
+
     elif command == "verify":
         verification_token = args.verification_token
         digital_twin_info = client.verify_digital_twin_email(verification_token)
@@ -1889,6 +1909,25 @@ Property ID and value of the property where the value is a reference
         else:
             print("Invalid invitation response")
 
+    elif command == "register_digital_twin_without_credential":
+        tenant_id = args.tenant_id
+        properties = []
+        definition1 = attributes.PropertyDefinition(
+                property="extid"
+            )
+        property1 = helper.create_property(definition1, None, "44")
+        properties.append(property1)
+        register_response = client.register_digital_twin_without_credential(
+            tenant_id,
+            1,
+            [],
+            properties,
+            [])
+        if register_response is not None:
+            print_response(register_response)
+        else:
+            print("Invalid invitation response")
+
 
 def print_verify_info(digital_twin_info):  # pragma: no cover
     print("Digital twin info")
