@@ -1,7 +1,7 @@
 import certifi
 import grpc
 import os
-import indykite_sdk.utils.logger as logger
+import sys
 from indykite_sdk.identity import helper
 from indykite_sdk.indykite.identity.v1beta2 import identity_management_api_pb2_grpc as pb2_grpc
 
@@ -46,12 +46,13 @@ class IdentityClient(object):
             self.stub = pb2_grpc.IdentityManagementAPIStub(channel=self.channel)
 
         except Exception as exception:
-            return logger.logger_error(exception)
+            tb = sys.exception().__traceback__
+            raise exception(...).with_traceback(tb)
 
     # Imported methods
     from .change_password import change_password_of_user, change_password
     from .get_digital_twin import get_digital_twin_by_token, get_digital_twin
-    from .introspect_token import introspect_token
+    from .token_introspect import token_introspect, session_introspect
     from .patch_properties import patch_properties_by_token, patch_properties
     from .verification import start_digital_twin_email_verification, verify_digital_twin_email
     from .delete import del_digital_twin, del_digital_twin_by_token
@@ -60,3 +61,4 @@ class IdentityClient(object):
     from .consent import create_consent, list_consents, revoke_consent
     from .forgotten_password import start_forgotten_password_flow
     from .invitation import create_email_invitation, create_mobile_invitation, check_invitation_state, resend_invitation, cancel_invitation
+    from .register_digital_twins_no_cred import register_digital_twin_without_credential
